/**
 * MaterialIcons icon set component.
 * Usage: <MaterialIcons name="icon-name" size={20} color="#4F8EF7" />
 *
 * @providesModule MaterialIcons
 */
'use strict';

var createIconSet = require('./lib/create-icon-set');
var glyphMap = {
  "3d-rotation": 61696,
  "access-alarm": 61697,
  "access-alarms": 61698,
  "access-time": 61699,
  "accessibility": 61700,
  "account-balance": 61701,
  "account-balance-wallet": 61702,
  "account-box": 61703,
  "account-circle": 61704,
  "adb": 61705,
  "add": 61706,
  "add-alarm": 61707,
  "add-alert": 61708,
  "add-box": 61709,
  "add-circle": 61710,
  "add-circle-outline": 61711,
  "add-shopping-cart": 61712,
  "add-to-photos": 61713,
  "adjust": 61714,
  "airline-seat-flat": 61715,
  "airline-seat-flat-angled": 61716,
  "airline-seat-individual-suite": 61717,
  "airline-seat-legroom-extra": 61718,
  "airline-seat-legroom-normal": 61719,
  "airline-seat-legroom-reduced": 61720,
  "airline-seat-recline-extra": 61721,
  "airline-seat-recline-normal": 61722,
  "airplanemode-active": 61723,
  "airplanemode-inactive": 61724,
  "airplay": 61725,
  "alarm": 61726,
  "alarm-add": 61727,
  "alarm-off": 61728,
  "alarm-on": 61729,
  "album": 61730,
  "android": 61731,
  "announcement": 61732,
  "apps": 61733,
  "archive": 61734,
  "arrow-back": 61735,
  "arrow-drop-down": 61736,
  "arrow-drop-down-circle": 61737,
  "arrow-drop-up": 61738,
  "arrow-forward": 61739,
  "aspect-ratio": 61740,
  "assessment": 61741,
  "assignment": 61742,
  "assignment-ind": 61743,
  "assignment-late": 61744,
  "assignment-return": 61745,
  "assignment-returned": 61746,
  "assignment-turned-in": 61747,
  "assistant": 61748,
  "assistant-photo": 61749,
  "attach-file": 61750,
  "attach-money": 61751,
  "attachment": 61752,
  "audiotrack": 61753,
  "autorenew": 61754,
  "av-timer": 61755,
  "backspace": 61756,
  "backup": 61757,
  "battery-20": 61758,
  "battery-30": 61759,
  "battery-50": 61760,
  "battery-60": 61761,
  "battery-80": 61762,
  "battery-90": 61763,
  "battery-alert": 61764,
  "battery-charging-20": 61765,
  "battery-charging-30": 61766,
  "battery-charging-50": 61767,
  "battery-charging-60": 61768,
  "battery-charging-80": 61769,
  "battery-charging-90": 61770,
  "battery-charging-full": 61771,
  "battery-full": 61772,
  "battery-std": 61773,
  "battery-unknown": 61774,
  "beenhere": 61775,
  "block": 61776,
  "bluetooth": 61777,
  "bluetooth-audio": 61778,
  "bluetooth-connected": 61779,
  "bluetooth-disabled": 61780,
  "bluetooth-searching": 61781,
  "blur-circular": 61782,
  "blur-linear": 61783,
  "blur-off": 61784,
  "blur-on": 61785,
  "book": 61786,
  "bookmark": 61787,
  "bookmark-border": 61788,
  "border-all": 61789,
  "border-bottom": 61790,
  "border-clear": 61791,
  "border-color": 61792,
  "border-horizontal": 61793,
  "border-inner": 61794,
  "border-left": 61795,
  "border-outer": 61796,
  "border-right": 61797,
  "border-style": 61798,
  "border-top": 61799,
  "border-vertical": 61800,
  "brightness-1": 61801,
  "brightness-2": 61802,
  "brightness-3": 61803,
  "brightness-4": 61804,
  "brightness-5": 61805,
  "brightness-6": 61806,
  "brightness-7": 61807,
  "brightness-auto": 61808,
  "brightness-high": 61809,
  "brightness-low": 61810,
  "brightness-medium": 61811,
  "broken-image": 61812,
  "brush": 61813,
  "bug-report": 61814,
  "build": 61815,
  "business": 61816,
  "cached": 61817,
  "cake": 61818,
  "call": 61819,
  "call-end": 61820,
  "call-made": 61821,
  "call-merge": 61822,
  "call-missed": 61823,
  "call-received": 61824,
  "call-split": 61825,
  "camera": 61826,
  "camera-alt": 61827,
  "camera-front": 61828,
  "camera-rear": 61829,
  "camera-roll": 61830,
  "cancel": 61831,
  "card-giftcard": 61832,
  "card-membership": 61833,
  "card-travel": 61834,
  "cast": 61835,
  "cast-connected": 61836,
  "center-focus-strong": 61837,
  "center-focus-weak": 61838,
  "change-history": 61839,
  "chat": 61840,
  "chat-bubble": 61841,
  "chat-bubble-outline": 61842,
  "check": 61843,
  "check-box": 61844,
  "check-box-outline-blank": 61845,
  "check-circle": 61846,
  "chevron-left": 61847,
  "chevron-right": 61848,
  "chrome-reader-mode": 61849,
  "class": 61850,
  "clear": 61851,
  "clear-all": 61852,
  "close": 61853,
  "closed-caption": 61854,
  "cloud": 61855,
  "cloud-circle": 61856,
  "cloud-done": 61857,
  "cloud-download": 61858,
  "cloud-off": 61859,
  "cloud-queue": 61860,
  "cloud-upload": 61861,
  "code": 61862,
  "collections": 61863,
  "color-lens": 61864,
  "colorize": 61865,
  "comment": 61866,
  "compare": 61867,
  "computer": 61868,
  "confirmation-number": 61869,
  "contact-phone": 61870,
  "contacts": 61871,
  "content-copy": 61872,
  "content-cut": 61873,
  "content-paste": 61874,
  "control-point": 61875,
  "control-point-duplicate": 61876,
  "create": 61877,
  "credit-card": 61878,
  "crop": 61879,
  "crop-16-9": 61880,
  "crop-3-2": 61881,
  "crop-5-4": 61882,
  "crop-7-5": 61883,
  "crop-din": 61884,
  "crop-free": 61885,
  "crop-landscape": 61886,
  "crop-original": 61887,
  "crop-portrait": 61888,
  "crop-square": 61889,
  "dashboard": 61890,
  "data-usage": 61891,
  "dehaze": 61892,
  "delete": 61893,
  "description": 61894,
  "desktop-mac": 61895,
  "desktop-windows": 61896,
  "details": 61897,
  "developer-board": 61898,
  "developer-mode": 61899,
  "devices": 61900,
  "dialer-sip": 61901,
  "dialpad": 61902,
  "directions": 61903,
  "directions-bike": 61904,
  "directions-boat": 61905,
  "directions-bus": 61906,
  "directions-car": 61907,
  "directions-railway": 61908,
  "directions-run": 61909,
  "directions-subway": 61910,
  "directions-transit": 61911,
  "directions-walk": 61912,
  "disc-full": 61913,
  "dns": 61914,
  "do-not-disturb": 61915,
  "do-not-disturb-alt": 61916,
  "dock": 61917,
  "domain": 61918,
  "done": 61919,
  "done-all": 61920,
  "drafts": 61921,
  "drive-eta": 61922,
  "dvr": 61923,
  "edit": 61924,
  "email": 61925,
  "equalizer": 61926,
  "error": 61927,
  "error-outline": 61928,
  "event": 61929,
  "event-available": 61930,
  "event-busy": 61931,
  "event-note": 61932,
  "event-seat": 61933,
  "exit-to-app": 61934,
  "expand-less": 61935,
  "expand-more": 61936,
  "explicit": 61937,
  "explore": 61938,
  "exposure": 61939,
  "exposure-neg-1": 61940,
  "exposure-neg-2": 61941,
  "exposure-plus-1": 61942,
  "exposure-plus-2": 61943,
  "exposure-zero": 61944,
  "extension": 61945,
  "face": 61946,
  "fast-forward": 61947,
  "fast-rewind": 61948,
  "favorite": 61949,
  "favorite-border": 61950,
  "feedback": 61951,
  "file-download": 61952,
  "file-upload": 61953,
  "filter": 61954,
  "filter-1": 61955,
  "filter-2": 61956,
  "filter-3": 61957,
  "filter-4": 61958,
  "filter-5": 61959,
  "filter-6": 61960,
  "filter-7": 61961,
  "filter-8": 61962,
  "filter-9": 61963,
  "filter-9-plus": 61964,
  "filter-b-and-w": 61965,
  "filter-center-focus": 61966,
  "filter-drama": 61967,
  "filter-frames": 61968,
  "filter-hdr": 61969,
  "filter-list": 61970,
  "filter-none": 61971,
  "filter-tilt-shift": 61972,
  "filter-vintage": 61973,
  "find-in-page": 61974,
  "find-replace": 61975,
  "flag": 61976,
  "flare": 61977,
  "flash-auto": 61978,
  "flash-off": 61979,
  "flash-on": 61980,
  "flight": 61981,
  "flight-land": 61982,
  "flight-takeoff": 61983,
  "flip": 61984,
  "flip-to-back": 61985,
  "flip-to-front": 61986,
  "folder": 61987,
  "folder-open": 61988,
  "folder-shared": 61989,
  "folder-special": 61990,
  "format-align-center": 61991,
  "format-align-justify": 61992,
  "format-align-left": 61993,
  "format-align-right": 61994,
  "format-bold": 61995,
  "format-clear": 61996,
  "format-color-fill": 61997,
  "format-color-reset": 61998,
  "format-color-text": 61999,
  "format-indent-decrease": 62000,
  "format-indent-increase": 62001,
  "format-italic": 62002,
  "format-line-spacing": 62003,
  "format-list-bulleted": 62004,
  "format-list-numbered": 62005,
  "format-paint": 62006,
  "format-quote": 62007,
  "format-size": 62008,
  "format-strikethrough": 62009,
  "format-textdirection-l-to-r": 62010,
  "format-textdirection-r-to-l": 62011,
  "format-underlined": 62012,
  "forum": 62013,
  "forward": 62014,
  "forward-10": 62015,
  "forward-30": 62016,
  "forward-5": 62017,
  "fullscreen": 62018,
  "fullscreen-exit": 62019,
  "functions": 62020,
  "gamepad": 62021,
  "games": 62022,
  "gesture": 62023,
  "get-app": 62024,
  "gps-fixed": 62025,
  "gps-not-fixed": 62026,
  "gps-off": 62027,
  "grade": 62028,
  "gradient": 62029,
  "grain": 62030,
  "graphic-eq": 62031,
  "grid-off": 62032,
  "grid-on": 62033,
  "group": 62034,
  "group-add": 62035,
  "group-work": 62036,
  "hdr-off": 62037,
  "hdr-on": 62038,
  "hdr-strong": 62039,
  "hdr-weak": 62040,
  "headset": 62041,
  "headset-mic": 62042,
  "healing": 62043,
  "hearing": 62044,
  "help": 62045,
  "high-quality": 62046,
  "highlight-off": 62047,
  "history": 62048,
  "home": 62049,
  "hotel": 62050,
  "hourglass-empty": 62051,
  "hourglass-full": 62052,
  "http": 62053,
  "https": 62054,
  "image": 62055,
  "image-aspect-ratio": 62056,
  "import-export": 62057,
  "inbox": 62058,
  "info": 62059,
  "info-outline": 62060,
  "input": 62061,
  "insert-chart": 62062,
  "insert-comment": 62063,
  "insert-drive-file": 62064,
  "insert-emoticon": 62065,
  "insert-invitation": 62066,
  "insert-link": 62067,
  "insert-photo": 62068,
  "invert-colors": 62069,
  "invert-colors-off": 62070,
  "iso": 62071,
  "keyboard": 62072,
  "keyboard-arrow-down": 62073,
  "keyboard-arrow-left": 62074,
  "keyboard-arrow-right": 62075,
  "keyboard-arrow-up": 62076,
  "keyboard-backspace": 62077,
  "keyboard-capslock": 62078,
  "keyboard-hide": 62079,
  "keyboard-return": 62080,
  "keyboard-tab": 62081,
  "keyboard-voice": 62082,
  "label": 62083,
  "label-outline": 62084,
  "landscape": 62085,
  "language": 62086,
  "laptop": 62087,
  "laptop-chromebook": 62088,
  "laptop-mac": 62089,
  "laptop-windows": 62090,
  "launch": 62091,
  "layers": 62092,
  "layers-clear": 62093,
  "leak-add": 62094,
  "leak-remove": 62095,
  "lens": 62096,
  "library-add": 62097,
  "library-books": 62098,
  "library-music": 62099,
  "link": 62100,
  "list": 62101,
  "live-help": 62102,
  "live-tv": 62103,
  "local-activity": 62104,
  "local-airport": 62105,
  "local-atm": 62106,
  "local-bar": 62107,
  "local-cafe": 62108,
  "local-car-wash": 62109,
  "local-convenience-store": 62110,
  "local-dining": 62111,
  "local-drink": 62112,
  "local-florist": 62113,
  "local-gas-station": 62114,
  "local-grocery-store": 62115,
  "local-hospital": 62116,
  "local-hotel": 62117,
  "local-laundry-service": 62118,
  "local-library": 62119,
  "local-mall": 62120,
  "local-movies": 62121,
  "local-offer": 62122,
  "local-parking": 62123,
  "local-pharmacy": 62124,
  "local-phone": 62125,
  "local-pizza": 62126,
  "local-play": 62127,
  "local-post-office": 62128,
  "local-printshop": 62129,
  "local-see": 62130,
  "local-shipping": 62131,
  "local-taxi": 62132,
  "location-city": 62133,
  "location-disabled": 62134,
  "location-off": 62135,
  "location-on": 62136,
  "location-searching": 62137,
  "lock": 62138,
  "lock-open": 62139,
  "lock-outline": 62140,
  "looks": 62141,
  "looks-3": 62142,
  "looks-4": 62143,
  "looks-5": 62144,
  "looks-6": 62145,
  "looks-one": 62146,
  "looks-two": 62147,
  "loop": 62148,
  "loupe": 62149,
  "loyalty": 62150,
  "mail": 62151,
  "map": 62152,
  "markunread": 62153,
  "markunread-mailbox": 62154,
  "memory": 62155,
  "menu": 62156,
  "merge-type": 62157,
  "message": 62158,
  "mic": 62159,
  "mic-none": 62160,
  "mic-off": 62161,
  "mms": 62162,
  "mode-comment": 62163,
  "mode-edit": 62164,
  "monochrome-photos": 62165,
  "mood": 62166,
  "mood-bad": 62167,
  "more": 62168,
  "more-horiz": 62169,
  "more-vert": 62170,
  "mouse": 62171,
  "movie": 62172,
  "movie-creation": 62173,
  "music-note": 62174,
  "my-location": 62175,
  "nature": 62176,
  "nature-people": 62177,
  "navigate-before": 62178,
  "navigate-next": 62179,
  "navigation": 62180,
  "network-cell": 62181,
  "network-locked": 62182,
  "network-wifi": 62183,
  "new-releases": 62184,
  "nfc": 62185,
  "no-sim": 62186,
  "not-interested": 62187,
  "note-add": 62188,
  "notifications": 62189,
  "notifications-active": 62190,
  "notifications-none": 62191,
  "notifications-off": 62192,
  "notifications-paused": 62193,
  "ondemand-video": 62194,
  "open-in-browser": 62195,
  "open-in-new": 62196,
  "open-with": 62197,
  "pages": 62198,
  "pageview": 62199,
  "palette": 62200,
  "panorama": 62201,
  "panorama-fish-eye": 62202,
  "panorama-horizontal": 62203,
  "panorama-vertical": 62204,
  "panorama-wide-angle": 62205,
  "party-mode": 62206,
  "pause": 62207,
  "pause-circle-filled": 62208,
  "pause-circle-outline": 62209,
  "payment": 62210,
  "people": 62211,
  "people-outline": 62212,
  "perm-camera-mic": 62213,
  "perm-contact-calendar": 62214,
  "perm-data-setting": 62215,
  "perm-device-information": 62216,
  "perm-identity": 62217,
  "perm-media": 62218,
  "perm-phone-msg": 62219,
  "perm-scan-wifi": 62220,
  "person": 62221,
  "person-add": 62222,
  "person-outline": 62223,
  "person-pin": 62224,
  "personal-video": 62225,
  "phone": 62226,
  "phone-android": 62227,
  "phone-bluetooth-speaker": 62228,
  "phone-forwarded": 62229,
  "phone-in-talk": 62230,
  "phone-iphone": 62231,
  "phone-locked": 62232,
  "phone-missed": 62233,
  "phone-paused": 62234,
  "phonelink": 62235,
  "phonelink-off": 62236,
  "photo": 62237,
  "photo-album": 62238,
  "photo-camera": 62239,
  "photo-library": 62240,
  "picture-as-pdf": 62241,
  "picture-in-picture": 62242,
  "pin-drop": 62243,
  "place": 62244,
  "play-arrow": 62245,
  "play-circle-filled": 62246,
  "play-circle-outline": 62247,
  "play-for-work": 62248,
  "playlist-add": 62249,
  "plus-one": 62250,
  "poll": 62251,
  "polymer": 62252,
  "portable-wifi-off": 62253,
  "portrait": 62254,
  "power": 62255,
  "power-input": 62256,
  "power-settings-new": 62257,
  "present-to-all": 62258,
  "print": 62259,
  "public": 62260,
  "publish": 62261,
  "query-builder": 62262,
  "question-answer": 62263,
  "queue": 62264,
  "queue-music": 62265,
  "radio": 62266,
  "radio-button-checked": 62267,
  "radio-button-unchecked": 62268,
  "rate-review": 62269,
  "receipt": 62270,
  "recent-actors": 62271,
  "redeem": 62272,
  "redo": 62273,
  "refresh": 62274,
  "remove": 62275,
  "remove-circle": 62276,
  "remove-circle-outline": 62277,
  "remove-red-eye": 62278,
  "repeat": 62279,
  "repeat-one": 62280,
  "replay": 62281,
  "replay-10": 62282,
  "replay-30": 62283,
  "replay-5": 62284,
  "reply": 62285,
  "reply-all": 62286,
  "report": 62287,
  "report-problem": 62288,
  "restaurant-menu": 62289,
  "restore": 62290,
  "ring-volume": 62291,
  "room": 62292,
  "rotate-90-degrees-ccw": 62293,
  "rotate-left": 62294,
  "rotate-right": 62295,
  "router": 62296,
  "satellite": 62297,
  "save": 62298,
  "scanner": 62299,
  "schedule": 62300,
  "school": 62301,
  "screen-lock-landscape": 62302,
  "screen-lock-portrait": 62303,
  "screen-lock-rotation": 62304,
  "screen-rotation": 62305,
  "sd-card": 62306,
  "sd-storage": 62307,
  "search": 62308,
  "security": 62309,
  "select-all": 62310,
  "send": 62311,
  "settings": 62312,
  "settings-applications": 62313,
  "settings-backup-restore": 62314,
  "settings-bluetooth": 62315,
  "settings-brightness": 62316,
  "settings-cell": 62317,
  "settings-ethernet": 62318,
  "settings-input-antenna": 62319,
  "settings-input-component": 62320,
  "settings-input-composite": 62321,
  "settings-input-hdmi": 62322,
  "settings-input-svideo": 62323,
  "settings-overscan": 62324,
  "settings-phone": 62325,
  "settings-power": 62326,
  "settings-remote": 62327,
  "settings-system-daydream": 62328,
  "settings-voice": 62329,
  "share": 62330,
  "shop": 62331,
  "shop-two": 62332,
  "shopping-basket": 62333,
  "shopping-cart": 62334,
  "shuffle": 62335,
  "signal-cellular-0-bar": 62336,
  "signal-cellular-1-bar": 62337,
  "signal-cellular-2-bar": 62338,
  "signal-cellular-3-bar": 62339,
  "signal-cellular-4-bar": 62340,
  "signal-cellular-connected-no-internet-0-bar": 62341,
  "signal-cellular-connected-no-internet-1-bar": 62342,
  "signal-cellular-connected-no-internet-2-bar": 62343,
  "signal-cellular-connected-no-internet-3-bar": 62344,
  "signal-cellular-connected-no-internet-4-bar": 62345,
  "signal-cellular-no-sim": 62346,
  "signal-cellular-null": 62347,
  "signal-cellular-off": 62348,
  "signal-wifi-0-bar": 62349,
  "signal-wifi-1-bar": 62350,
  "signal-wifi-1-bar-lock": 62351,
  "signal-wifi-2-bar": 62352,
  "signal-wifi-2-bar-lock": 62353,
  "signal-wifi-3-bar": 62354,
  "signal-wifi-3-bar-lock": 62355,
  "signal-wifi-4-bar": 62356,
  "signal-wifi-4-bar-lock": 62357,
  "signal-wifi-off": 62358,
  "sim-card": 62359,
  "sim-card-alert": 62360,
  "skip-next": 62361,
  "skip-previous": 62362,
  "slideshow": 62363,
  "smartphone": 62364,
  "sms": 62365,
  "sms-failed": 62366,
  "snooze": 62367,
  "sort": 62368,
  "space-bar": 62369,
  "speaker": 62370,
  "speaker-group": 62371,
  "speaker-notes": 62372,
  "speaker-phone": 62373,
  "spellcheck": 62374,
  "stars": 62375,
  "stay-current-landscape": 62376,
  "stay-current-portrait": 62377,
  "stay-primary-landscape": 62378,
  "stay-primary-portrait": 62379,
  "stop": 62380,
  "storage": 62381,
  "store": 62382,
  "store-mall-directory": 62383,
  "straighten": 62384,
  "strikethrough-s": 62385,
  "style": 62386,
  "subject": 62387,
  "subtitles": 62388,
  "supervisor-account": 62389,
  "surround-sound": 62390,
  "swap-calls": 62391,
  "swap-horiz": 62392,
  "swap-vert": 62393,
  "swap-vertical-circle": 62394,
  "switch-camera": 62395,
  "switch-video": 62396,
  "sync": 62397,
  "sync-disabled": 62398,
  "sync-problem": 62399,
  "system-update": 62400,
  "system-update-alt": 62401,
  "tab": 62402,
  "tab-unselected": 62403,
  "tablet": 62404,
  "tablet-android": 62405,
  "tablet-mac": 62406,
  "tag-faces": 62407,
  "tap-and-play": 62408,
  "terrain": 62409,
  "text-format": 62410,
  "textsms": 62411,
  "texture": 62412,
  "theaters": 62413,
  "thumb-down": 62414,
  "thumb-up": 62415,
  "thumbs-up-down": 62416,
  "time-to-leave": 62417,
  "timelapse": 62418,
  "timer": 62419,
  "timer-10": 62420,
  "timer-3": 62421,
  "timer-off": 62422,
  "toc": 62423,
  "today": 62424,
  "toll": 62425,
  "tonality": 62426,
  "toys": 62427,
  "track-changes": 62428,
  "traffic": 62429,
  "transform": 62430,
  "translate": 62431,
  "trending-down": 62432,
  "trending-flat": 62433,
  "trending-up": 62434,
  "tune": 62435,
  "turned-in": 62436,
  "turned-in-not": 62437,
  "tv": 62438,
  "undo": 62439,
  "unfold-less": 62440,
  "unfold-more": 62441,
  "usb": 62442,
  "verified-user": 62443,
  "vertical-align-bottom": 62444,
  "vertical-align-center": 62445,
  "vertical-align-top": 62446,
  "vibration": 62447,
  "video-library": 62448,
  "videocam": 62449,
  "videocam-off": 62450,
  "view-agenda": 62451,
  "view-array": 62452,
  "view-carousel": 62453,
  "view-column": 62454,
  "view-comfy": 62455,
  "view-compact": 62456,
  "view-day": 62457,
  "view-headline": 62458,
  "view-list": 62459,
  "view-module": 62460,
  "view-quilt": 62461,
  "view-stream": 62462,
  "view-week": 62463,
  "visibility": 62464,
  "visibility-off": 62465,
  "voice-chat": 62466,
  "voicemail": 62467,
  "volume-down": 62468,
  "volume-mute": 62469,
  "volume-off": 62470,
  "volume-up": 62471,
  "vpn-key": 62472,
  "vpn-lock": 62473,
  "wallpaper": 62474,
  "warning": 62475,
  "watch": 62476,
  "wb-auto": 62477,
  "wb-cloudy": 62478,
  "wb-incandescent": 62479,
  "wb-iridescent": 62480,
  "wb-sunny": 62481,
  "wc": 62482,
  "web": 62483,
  "whatshot": 62484,
  "widgets": 62485,
  "wifi": 62486,
  "wifi-lock": 62487,
  "wifi-tethering": 62488,
  "work": 62489,
  "wrap-text": 62490,
  "youtube-searched-for": 62491
};

var MaterialIcons = createIconSet(glyphMap, 'MaterialIcons', 'MaterialIcons.ttf');

module.exports = MaterialIcons;
module.exports.glyphMap = glyphMap;

